package pps.core.base.service;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import pps.core.base.entity.ConfigOilFieldEnt;
import pps.core.base.mapper.ConfigOilFieldMapper;
import pps.core.base.service.data.config_oil_field.GetConfigOilFieldOutput;
import pps.core.base.service.data.config_oil_field.GetProjectTitleOutput;
import pps.core.common.constant.BusinessConstant;
import xstartup.annotation.XService;
import xstartup.base.XContext;
import xstartup.base.XStartup;
import xstartup.data.XSingleResult;
import xstartup.feature.api.annotation.XApiGet;

import java.util.List;

/**
 * 油田配置模块
 *
 * @author ZWT
 * @date 2024/06/25
 */
@XService
public class ConfigOilFieldService {

    private static final String storeDir = XStartup.getCurrent().getProperty("home.image.path");

    /**
     * 获取当前配置
     *
     * @param context 上下文
     * @return {@link XSingleResult }<{@link GetConfigOilFieldOutput }>
     */
    @XApiGet(anonymous = true)
    public XSingleResult<GetConfigOilFieldOutput> getCurrentConfig(XContext context) {
        ConfigOilFieldMapper mapper = context.getBean(ConfigOilFieldMapper.class);
        ConfigOilFieldEnt ent = mapper.selectOne(new LambdaQueryWrapper<ConfigOilFieldEnt>()
                .eq(ConfigOilFieldEnt::getIsEnable, BusinessConstant.ZERO)
                .last(BusinessConstant.LAST_LIMIT)
        );
        List<GetProjectTitleOutput> list = JSONUtil.toList(ent.getProjectTitle(), GetProjectTitleOutput.class);
        GetProjectTitleOutput output = list.stream()
                .filter(t -> ObjectUtil.isNotNull(t.getSort()) && ObjectUtil.equals(0, t.getSort()))
                .findAny()
                .orElse(new GetProjectTitleOutput());
        return XSingleResult.success(GetConfigOilFieldOutput.builder()
                .title(output.getTitle())
                .homePagePath(ent.getHomePagePath())
                .imagePath(storeDir + FileUtil.FILE_SEPARATOR + output.getImageRelativePath())
                .build());
    }
}